<?php

namespace Drupal\yandex_yml\Xml;

/**
 * Interface ElementInterface.
 *
 * @package Drupal\yandex_yml\Xml
 */
interface ElementInterface {

  /**
   * Gets element attributes.
   *
   * @return \Drupal\yandex_yml\Xml\AttributeInterface[]
   *   An array with attribute elements.
   */
  public function getElementAttributes();

  /**
   * Sets element attributes.
   *
   * @param array $attributes
   *   An array with attribute elements.
   *
   * @return \Drupal\yandex_yml\Xml\ElementInterface
   *   The current instance of element.
   */
  public function setElementAttributes(array $attributes);

  /**
   * Adds attribute for element.
   *
   * @param \Drupal\yandex_yml\Xml\AttributeInterface $attribute
   *   The attribute which needs to be added to element for which called method.
   *
   * @return \Drupal\yandex_yml\Xml\ElementInterface
   *   The current instance of element.
   */
  public function addElementAttribute(AttributeInterface $attribute);

  /**
   * Gets element children.
   *
   * @return \Drupal\yandex_yml\Xml\ElementInterface[]
   *   An array with children elements.
   */
  public function getElementChildren();

  /**
   * Adds child element.
   *
   * @param \Drupal\yandex_yml\Xml\ElementInterface $element
   *   An element to add to children.
   *
   * @return \Drupal\yandex_yml\Xml\ElementInterface
   *   The current instance of element.
   */
  public function addElementChild(ElementInterface $element);

  /**
   * Gets element name.
   *
   * @return string
   *   The element name.
   */
  public function getElementName();

  /**
   * Gets element value.
   *
   * @return mixed
   *   An element value.
   */
  public function getElementValue();

  /**
   * Gets CDATA status mark.
   *
   * @return bool
   *   The CDATA status.
   */
  public function getCdata();

}
